============
OeREB Client
============

|build status| |coverage report|


OEREB Client is a web application based on AngularJS, OpenLayers 3 and Bootstrap.

It is used as client application for the OEREB Server (pyramid_oereb_).

For detailed information, please refer to the documentation_.

.. _pyramid_oereb: https://github.com/openoereb/pyramid_oereb
.. _documentation: https://gf-bl.gitlab.io/oereb/oereb_client
.. |build status| image:: https://gitlab.com/gf-bl/oereb/oereb_client/badges/master/pipeline.svg
   :target: https://gitlab.com/gf-bl/oereb/oereb_client/commits/master
.. |coverage report| image:: https://gitlab.com/gf-bl/oereb/oereb_client/badges/master/coverage.svg
   :target: https://gitlab.com/gf-bl/oereb/oereb_client/commits/master
